import { AccessLevelList } from '../../shared/access-level';
import { PolicyStatement, Operator } from '../../shared';
/**
 * Statement provider for service [neptune-graph](https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonneptuneanalytics.html).
 *
 * @param sid [SID](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_sid.html) of the statement
 */
export declare class NeptuneGraph extends PolicyStatement {
    servicePrefix: string;
    /**
     * Statement provider for service [neptune-graph](https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonneptuneanalytics.html).
     *
     * @param sid [SID](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_sid.html) of the statement
     */
    constructor(sid?: string);
    /**
     * Grants permission to cancel an ongoing import task
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/neptune-analytics/latest/userguide/iam-actions.html#CancelImportTask
     */
    toCancelImportTask(): this;
    /**
     * Grants permission to cancel a query
     *
     * Access Level: Write
     *
     * Possible conditions:
     * - .ifAwsResourceTag()
     *
     * https://docs.aws.amazon.com/neptune-analytics/latest/userguide/iam-actions.html#CancelQuery
     */
    toCancelQuery(): this;
    /**
     * Grants permission to create a new graph
     *
     * Access Level: Write
     *
     * Possible conditions:
     * - .ifAwsRequestTag()
     * - .ifAwsTagKeys()
     *
     * Dependent actions:
     * - iam:CreateServiceLinkedRole
     * - kms:CreateGrant
     * - kms:Decrypt
     * - kms:DescribeKey
     *
     * https://docs.aws.amazon.com/neptune-analytics/latest/userguide/iam-actions.html#CreateGraph
     */
    toCreateGraph(): this;
    /**
     * Grants permission to create a new snapshot from an existing graph
     *
     * Access Level: Write
     *
     * Possible conditions:
     * - .ifAwsRequestTag()
     * - .ifAwsResourceTag()
     * - .ifAwsTagKeys()
     *
     * https://docs.aws.amazon.com/neptune-analytics/latest/userguide/iam-actions.html#CreateGraphSnapshot
     */
    toCreateGraphSnapshot(): this;
    /**
     * Grants permission to create a new graph while importing data into the new graph
     *
     * Access Level: Write
     *
     * Possible conditions:
     * - .ifAwsRequestTag()
     * - .ifAwsTagKeys()
     *
     * Dependent actions:
     * - iam:CreateServiceLinkedRole
     * - iam:PassRole
     * - kms:CreateGrant
     * - kms:Decrypt
     * - kms:DescribeKey
     *
     * https://docs.aws.amazon.com/neptune-analytics/latest/userguide/iam-actions.html#CreateGraphUsingImportTask
     */
    toCreateGraphUsingImportTask(): this;
    /**
     * Grants permission to create a new private graph endpoint to access the graph from within a vpc
     *
     * Access Level: Write
     *
     * Possible conditions:
     * - .ifAwsRequestTag()
     * - .ifAwsResourceTag()
     * - .ifAwsTagKeys()
     *
     * Dependent actions:
     * - ec2:CreateVpcEndpoint
     * - ec2:DescribeAvailabilityZones
     * - ec2:DescribeSecurityGroups
     * - ec2:DescribeSubnets
     * - ec2:DescribeVpcAttribute
     * - ec2:DescribeVpcEndpoints
     * - ec2:DescribeVpcs
     * - ec2:ModifyVpcEndpoint
     * - route53:AssociateVPCWithHostedZone
     *
     * https://docs.aws.amazon.com/neptune-analytics/latest/userguide/iam-actions.html#CreatePrivateGraphEndpoint
     */
    toCreatePrivateGraphEndpoint(): this;
    /**
     * Grants permission to delete data via query APIs on the graph
     *
     * Access Level: Write
     *
     * Possible conditions:
     * - .ifAwsResourceTag()
     *
     * https://docs.aws.amazon.com/neptune-analytics/latest/userguide/iam-actions.html#DeleteDataViaQuery
     */
    toDeleteDataViaQuery(): this;
    /**
     * Grants permission to delete a graph
     *
     * Access Level: Write
     *
     * Possible conditions:
     * - .ifAwsResourceTag()
     *
     * https://docs.aws.amazon.com/neptune-analytics/latest/userguide/iam-actions.html#DeleteGraph
     */
    toDeleteGraph(): this;
    /**
     * Grants permission to delete a snapshot
     *
     * Access Level: Write
     *
     * Possible conditions:
     * - .ifAwsResourceTag()
     *
     * https://docs.aws.amazon.com/neptune-analytics/latest/userguide/iam-actions.html#DeleteGraphSnapshot
     */
    toDeleteGraphSnapshot(): this;
    /**
     * Grants permission to delete a private graph endpoint of a graph
     *
     * Access Level: Write
     *
     * Possible conditions:
     * - .ifAwsResourceTag()
     *
     * Dependent actions:
     * - ec2:DeleteVpcEndpoints
     * - ec2:DescribeAvailabilityZones
     * - ec2:DescribeSecurityGroups
     * - ec2:DescribeSubnets
     * - ec2:DescribeVpcAttribute
     * - ec2:DescribeVpcEndpoints
     * - ec2:DescribeVpcs
     * - ec2:ModifyVpcEndpoint
     * - route53:DisassociateVPCFromHostedZone
     *
     * https://docs.aws.amazon.com/neptune-analytics/latest/userguide/iam-actions.html#DeletePrivateGraphEndpoint
     */
    toDeletePrivateGraphEndpoint(): this;
    /**
     * Grants permission to get the engine status of the graph
     *
     * Access Level: Read
     *
     * Possible conditions:
     * - .ifAwsResourceTag()
     *
     * https://docs.aws.amazon.com/neptune-analytics/latest/userguide/iam-actions.html#GetEngineStatus
     */
    toGetEngineStatus(): this;
    /**
     * Grants permission to get details about a graph
     *
     * Access Level: Read
     *
     * Possible conditions:
     * - .ifAwsResourceTag()
     *
     * https://docs.aws.amazon.com/neptune-analytics/latest/userguide/iam-actions.html#GetGraph
     */
    toGetGraph(): this;
    /**
     * Grants permission to get details about a snapshot
     *
     * Access Level: Read
     *
     * Possible conditions:
     * - .ifAwsResourceTag()
     *
     * https://docs.aws.amazon.com/neptune-analytics/latest/userguide/iam-actions.html#GetGraphSnapshot
     */
    toGetGraphSnapshot(): this;
    /**
     * Grants permission to get the summary for the data in the graph
     *
     * Access Level: Read
     *
     * Possible conditions:
     * - .ifAwsResourceTag()
     *
     * https://docs.aws.amazon.com/neptune-analytics/latest/userguide/iam-actions.html#GetGraphSummary
     */
    toGetGraphSummary(): this;
    /**
     * Grants permission to get details about an import task
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/neptune-analytics/latest/userguide/iam-actions.html#GetImportTask
     */
    toGetImportTask(): this;
    /**
     * Grants permission to get details about a private graph endpoint of a graph
     *
     * Access Level: Read
     *
     * Possible conditions:
     * - .ifAwsResourceTag()
     *
     * https://docs.aws.amazon.com/neptune-analytics/latest/userguide/iam-actions.html#GetPrivateGraphEndpoint
     */
    toGetPrivateGraphEndpoint(): this;
    /**
     * Grants permission to check the status of a given query
     *
     * Access Level: Read
     *
     * Possible conditions:
     * - .ifAwsResourceTag()
     *
     * https://docs.aws.amazon.com/neptune-analytics/latest/userguide/iam-actions.html#GetQueryStatus
     */
    toGetQueryStatus(): this;
    /**
     * Grants permission to get the statistics for the data in the graph
     *
     * Access Level: Read
     *
     * Possible conditions:
     * - .ifAwsResourceTag()
     *
     * https://docs.aws.amazon.com/neptune-analytics/latest/userguide/iam-actions.html#GetStatisticsStatus
     */
    toGetStatisticsStatus(): this;
    /**
     * Grants permission to list the snapshots in your account
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/neptune-analytics/latest/userguide/iam-actions.html#ListGraphSnapshots
     */
    toListGraphSnapshots(): this;
    /**
     * Grants permission to list the graphs in your account
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/neptune-analytics/latest/userguide/iam-actions.html#ListGraphs
     */
    toListGraphs(): this;
    /**
     * Grants permission to list the import tasks in your account
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/neptune-analytics/latest/userguide/iam-actions.html#ListImportTasks
     */
    toListImportTasks(): this;
    /**
     * Grants permission to list the private graph endpoints for a given graph
     *
     * Access Level: Read
     *
     * Possible conditions:
     * - .ifAwsResourceTag()
     *
     * https://docs.aws.amazon.com/neptune-analytics/latest/userguide/iam-actions.html#ListPrivateGraphEndpoints
     */
    toListPrivateGraphEndpoints(): this;
    /**
     * Grants permission to check the status of all active queries
     *
     * Access Level: Read
     *
     * Possible conditions:
     * - .ifAwsResourceTag()
     *
     * https://docs.aws.amazon.com/neptune-analytics/latest/userguide/iam-actions.html#ListQueries
     */
    toListQueries(): this;
    /**
     * Grants permission to lists tag for a Neptune Analytics resource
     *
     * Access Level: Read
     *
     * Possible conditions:
     * - .ifAwsResourceTag()
     *
     * https://docs.aws.amazon.com/neptune-analytics/latest/userguide/iam-actions.html#ListTagsForResource
     */
    toListTagsForResource(): this;
    /**
     * Grants permission to read data via query APIs on the graph
     *
     * Access Level: Read
     *
     * Possible conditions:
     * - .ifAwsResourceTag()
     *
     * https://docs.aws.amazon.com/neptune-analytics/latest/userguide/iam-actions.html#ReadDataViaQuery
     */
    toReadDataViaQuery(): this;
    /**
     * Grants permission to reset a graph which deletes all data within the graph
     *
     * Access Level: Write
     *
     * Possible conditions:
     * - .ifAwsResourceTag()
     *
     * https://docs.aws.amazon.com/neptune-analytics/latest/userguide/iam-actions.html#ResetGraph
     */
    toResetGraph(): this;
    /**
     * Grants permission to create a new graph from an existing snapshot
     *
     * Access Level: Write
     *
     * Possible conditions:
     * - .ifAwsRequestTag()
     * - .ifAwsResourceTag()
     * - .ifAwsTagKeys()
     *
     * Dependent actions:
     * - kms:CreateGrant
     * - kms:Decrypt
     * - kms:DescribeKey
     *
     * https://docs.aws.amazon.com/neptune-analytics/latest/userguide/iam-actions.html#RestoreGraphFromSnapshot
     */
    toRestoreGraphFromSnapshot(): this;
    /**
     * Grants permission to import data into an existing graph
     *
     * Access Level: Write
     *
     * Dependent actions:
     * - iam:PassRole
     *
     * https://docs.aws.amazon.com/neptune-analytics/latest/userguide/iam-actions.html#StartImportTask
     */
    toStartImportTask(): this;
    /**
     * Grants permission to tag a Neptune Analytics resource
     *
     * Access Level: Tagging
     *
     * Possible conditions:
     * - .ifAwsTagKeys()
     * - .ifAwsRequestTag()
     *
     * https://docs.aws.amazon.com/neptune-analytics/latest/userguide/iam-actions.html#TagResource
     */
    toTagResource(): this;
    /**
     * Grants permission to untag a Neptune Analytics resource
     *
     * Access Level: Tagging
     *
     * Possible conditions:
     * - .ifAwsTagKeys()
     *
     * https://docs.aws.amazon.com/neptune-analytics/latest/userguide/iam-actions.html#UntagResource
     */
    toUntagResource(): this;
    /**
     * Grants permission to modify a graph
     *
     * Access Level: Write
     *
     * Possible conditions:
     * - .ifAwsResourceTag()
     *
     * https://docs.aws.amazon.com/neptune-analytics/latest/userguide/iam-actions.html#UpdateGraph
     */
    toUpdateGraph(): this;
    /**
     * Grants permission to write data via query APIs on the graph
     *
     * Access Level: Write
     *
     * Possible conditions:
     * - .ifAwsResourceTag()
     *
     * https://docs.aws.amazon.com/neptune-analytics/latest/userguide/iam-actions.html#WriteDataViaQuery
     */
    toWriteDataViaQuery(): this;
    protected accessLevelList: AccessLevelList;
    /**
     * Adds a resource of type graph to the statement
     *
     * https://docs.aws.amazon.com/neptune-analytics/latest/userguide/iam-resources.html#graph
     *
     * @param resourceId - Identifier for the resourceId.
     * @param account - Account of the resource; defaults to `*`, unless using the CDK, where the default is the current Stack's account.
     * @param region - Region of the resource; defaults to `*`, unless using the CDK, where the default is the current Stack's region.
     * @param partition - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to `aws`, unless using the CDK, where the default is the current Stack's partition.
     *
     * Possible conditions:
     * - .ifAwsResourceTag()
     */
    onGraph(resourceId: string, account?: string, region?: string, partition?: string): this;
    /**
     * Adds a resource of type graph-snapshot to the statement
     *
     * https://docs.aws.amazon.com/neptune-analytics/latest/userguide/iam-resources.html#graph-snapshot
     *
     * @param resourceId - Identifier for the resourceId.
     * @param account - Account of the resource; defaults to `*`, unless using the CDK, where the default is the current Stack's account.
     * @param region - Region of the resource; defaults to `*`, unless using the CDK, where the default is the current Stack's region.
     * @param partition - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to `aws`, unless using the CDK, where the default is the current Stack's partition.
     *
     * Possible conditions:
     * - .ifAwsResourceTag()
     */
    onGraphSnapshot(resourceId: string, account?: string, region?: string, partition?: string): this;
    /**
     * Adds a resource of type import-task to the statement
     *
     * https://docs.aws.amazon.com/neptune-analytics/latest/userguide/iam-resources.html#import-task
     *
     * @param resourceId - Identifier for the resourceId.
     * @param account - Account of the resource; defaults to `*`, unless using the CDK, where the default is the current Stack's account.
     * @param region - Region of the resource; defaults to `*`, unless using the CDK, where the default is the current Stack's region.
     * @param partition - Partition of the AWS account [aws, aws-cn, aws-us-gov]; defaults to `aws`, unless using the CDK, where the default is the current Stack's partition.
     */
    onImportTask(resourceId: string, account?: string, region?: string, partition?: string): this;
    /**
     * Filters access by a tag's key and value in a request
     *
     * https://docs.aws.amazon.com/neptune-analytics/latest/userguide/reference_policies_condition-keys.html#condition-keys-requesttag
     *
     * Applies to actions:
     * - .toCreateGraph()
     * - .toCreateGraphSnapshot()
     * - .toCreateGraphUsingImportTask()
     * - .toCreatePrivateGraphEndpoint()
     * - .toRestoreGraphFromSnapshot()
     * - .toTagResource()
     *
     * @param tagKey The tag key to check
     * @param value The value(s) to check
     * @param operator Works with [string operators](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String). **Default:** `StringLike`
     */
    ifAwsRequestTag(tagKey: string, value: string | string[], operator?: Operator | string): this;
    /**
     * Filters access by the presence of tag key-value pairs in the request
     *
     * https://docs.aws.amazon.com/neptune-analytics/latest/userguide/reference_policies_condition-keys.html#condition-keys-resourcetag
     *
     * Applies to actions:
     * - .toCancelQuery()
     * - .toCreateGraphSnapshot()
     * - .toCreatePrivateGraphEndpoint()
     * - .toDeleteDataViaQuery()
     * - .toDeleteGraph()
     * - .toDeleteGraphSnapshot()
     * - .toDeletePrivateGraphEndpoint()
     * - .toGetEngineStatus()
     * - .toGetGraph()
     * - .toGetGraphSnapshot()
     * - .toGetGraphSummary()
     * - .toGetPrivateGraphEndpoint()
     * - .toGetQueryStatus()
     * - .toGetStatisticsStatus()
     * - .toListPrivateGraphEndpoints()
     * - .toListQueries()
     * - .toListTagsForResource()
     * - .toReadDataViaQuery()
     * - .toResetGraph()
     * - .toRestoreGraphFromSnapshot()
     * - .toUpdateGraph()
     * - .toWriteDataViaQuery()
     *
     * Applies to resource types:
     * - graph
     * - graph-snapshot
     *
     * @param tagKey The tag key to check
     * @param value The value(s) to check
     * @param operator Works with [string operators](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String). **Default:** `StringLike`
     */
    ifAwsResourceTag(tagKey: string, value: string | string[], operator?: Operator | string): this;
    /**
     * Filters access by the tag keys in a request
     *
     * https://docs.aws.amazon.com/neptune-analytics/latest/userguide/reference_policies_condition-keys.html#condition-keys-tagkeys
     *
     * Applies to actions:
     * - .toCreateGraph()
     * - .toCreateGraphSnapshot()
     * - .toCreateGraphUsingImportTask()
     * - .toCreatePrivateGraphEndpoint()
     * - .toRestoreGraphFromSnapshot()
     * - .toTagResource()
     * - .toUntagResource()
     *
     * @param value The value(s) to check
     * @param operator Works with [string operators](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_condition_operators.html#Conditions_String). **Default:** `StringLike`
     */
    ifAwsTagKeys(value: string | string[], operator?: Operator | string): this;
}
